@@ -13,6 +13,9 @@ class oracle(object):
             maxcsize=db.res1("select max(length(column_name)) from all_tab_cols where owner='%s' and table_name='%s'" %(owner,oname))
             tdesc=db.res1("select comments from user_tab_comments where table_name=:1",[oname])
             oridata=[]
+            for col in db.exec2("select * from all_tab_cols where owner='%s' and table_name='%s' order by column_id" %(owner,oname)):
+                col["COLUMN_COMMENT"]=db.res1("select comments from user_col_comments where table_name=:n and column_name=:cn",n=oname,cn=col["COLUMN_NAME"])
+                oridata.append(col)
             for column_name,data_type,char_length,data_precision,data_scale,nullable,default_length,data_default in db.exec("select column_name,data_type,char_length,data_precision,data_scale,nullable,default_length,data_default from all_tab_cols where owner='%s' and table_name='%s' order by column_id" %(owner,oname)):
                 odata=odata+"  %s%*s" %(column_name,maxcsize-len(column_name)+1," ")
                 ctype="char"
